# eric7.SqlBrowser.SqlConnectionDialog

Module implementing a dialog to enter the connection parameters.

### Global Attributes

None

### Classes

SqlConnectionDialog | Class implementing a dialog to enter the connection parameters.

### Functions

None

## SqlConnectionDialog

Class implementing a dialog to enter the connection parameters.

### Derived from

QDialog, Ui_SqlConnectionDialog

### Class Attributes

None

### Class Methods

None

### Methods

SqlConnectionDialog | Constructor
__updateDialog | Private slot to update the dialog depending on its contents.
getData | Public method to retrieve the connection data.
on_databasePicker_textChanged | Private slot handling the change of the database name.
on_driverCombo_activated | Private slot handling the selection of a database driver.

### Static Methods

None

#### SqlConnectionDialog (Constructor)

SqlConnectionDialog(parent=None)

Constructor

parent
  reference to the parent widget (QWidget)

#### SqlConnectionDialog.__updateDialog

__updateDialog()

Private slot to update the dialog depending on its contents.

#### SqlConnectionDialog.getData

getData()

Public method to retrieve the connection data.

Return:
  tuple giving the driver name (string), the database name (string), the user name (string), the password (string), the host name (string) and the port (integer)

#### SqlConnectionDialog.on_databasePicker_textChanged

on_databasePicker_textChanged(txt)

Private slot handling the change of the database name.

txt
  text of the edit (string)

#### SqlConnectionDialog.on_driverCombo_activated

on_driverCombo_activated(index)

Private slot handling the selection of a database driver.

index (int)
  index of the selected entry

Up